# llm_package

A Python Library to download all the required LLM Python packages for building an LLM-based chatbot

Please remember, you should already have Python (>3.8) installed on your device.

## Installation

```bash
pip install .
